<?php
/**
 * Bloog Lite functions and definitions
 *
 * @package Bloog Lite
 */

if ( ! function_exists( 'bloog_lite_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function bloog_lite_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Bloog Lite, use a find and replace
	 * to change 'bloog-lite' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'bloog-lite', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary Menu', 'bloog-lite' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'bloog_lite_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}
endif; // bloog_lite_setup
add_action( 'after_setup_theme', 'bloog_lite_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function bloog_lite_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'bloog_lite_content_width', 640 );
}
add_action( 'after_setup_theme', 'bloog_lite_content_width', 0 );

//adding class to body boxed/full-width
function bloog_lite_bodyclass($classes){
	$classes[]= get_theme_mod('layout_option');
	return $classes;
}
add_filter('body_class','bloog_lite_bodyclass' );

/**
 * Enqueue scripts and styles.
 */
function bloog_lite_scripts() {
	$query_args = array('family' => 'Oswald:400,300,700|Raleway:400,300,300italic,400italic,600,600italic,700,700italic,800,800italic|Lato:400,300,700,900,100|Open+Sans:400,700');
	wp_enqueue_style('bloog-lite-google-fonts-css', add_query_arg($query_args, "//fonts.googleapis.com/css"));
	wp_enqueue_style( 'bloog-lite-style', get_stylesheet_uri() );
    wp_enqueue_style( 'bloog-lite-respond', get_template_directory_uri() . '/css/responsive.css', array() );

	wp_enqueue_script( 'bloog-lite-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );
    wp_enqueue_script( 'bloog-lite-customjs', get_template_directory_uri() . '/js/custom.js', array('jquery'), '4.2.2', true );
    
	wp_enqueue_script( 'bloog-lite-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );
    
    wp_enqueue_script ( 'bloog-lite-main-script', get_template_directory_uri() . '/js/main.js', array('jquery'), '', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'bloog_lite_scripts' );

/**
 *  Cropping image to a required size
 */
 add_image_size('bloog-post-image-size', 940, 627, true); // post image size 
 add_image_size('bloog-homeslider-image-size', 450, 300, true); // post image home slider size
 add_image_size('bloog-homepage_post_fullwidth',970,400,true); // home page full width image
 add_image_size('bloog-post-image-withsidebar', 650, 479, true); // home page with sidebar
 add_image_size('bloog-about-us-page-img', 380, 380, true); // home page with sidebar
 add_image_size('bloog-grid-view-img', 300, 200, true); // home page with sidebar
 add_image_size ('bloog-feature-page-img', 292, 169); // feature page image display in sidebar and footer sidebar
 add_image_size ('bloog-recent-post-thumb', 86, 57, true);
  
/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/bloog-functions.php';

/**
 * Load customizer line
 */
require get_template_directory() . '/inc/bloog-customizer.php';

/**
 * Load post dropdown selector
 */
require get_template_directory() . '/inc/post-dropdown.php';

/**
 * Load post dropdown selector
 */
require get_template_directory() . '/inc/category-dropdown.php';

/**
 *  Load bloog widgets in site
 */
 require get_template_directory() . '/inc/bloog-widgets.php';

/**
 *  Load bloog widgets in site
 */
 require get_template_directory() . '/inc/bloog-tgm.php';


/**
 * 8Degree More Themes
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

// Add stylesheet and JS for upsell page.
function bloog_lite_upsell_style() {
	wp_enqueue_style( 'upsell-style', get_template_directory_uri() . '/css/upsell.css');
}

// Add upsell page to the menu.
function bloog_lite_add_upsell() {
	$page = add_theme_page(
		__( 'More Themes', 'bloog-lite' ),
		__( 'More Themes', 'bloog-lite' ),
		'administrator',
		'bloog-lite-themes',
		'bloog_lite_display_upsell'
	);

	add_action( 'admin_print_styles-' . $page, 'bloog_lite_upsell_style' );
}
add_action( 'admin_menu', 'bloog_lite_add_upsell', 11 );

// Define markup for the upsell page.
function bloog_lite_display_upsell() {

	// Set template directory uri
	$directory_uri = get_template_directory_uri();
	?>
	<div class="wrap">
		<div class="container-fluid">
			<div id="upsell_container">  
				<div class="row">
					<div id="upsell_header" class="col-md-12">
						<h2>
							<a href="http://8degreethemes.com/" target="_blank">
								<img src="http://8degreethemes.com/wp-content/uploads/2015/05/logo.png"/>
							</a>
						</h2>

						<h3><?php _e( 'Product of 8Degree Themes', 'bloog-lite' ); ?></h3>
					</div>
				</div>

				<div id="upsell_themes" class="row">
					<?php
					// Set the argument array with author name.
					$args = array(
						'author' => '8degreethemes',
					);

					// Set the $request array.
					$request = array(
						'body' => array(
							'action'  => 'query_themes',
							'request' => serialize( (object)$args )
						)
					);
					$themes = bloog_lite_get_themes( $request );
					$active_theme = wp_get_theme()->get( 'Name' );
					$counter = 1;

					// For currently active theme.
					foreach ( $themes->themes as $theme ) {
						if( $active_theme == $theme->name ) {?>

							<div id="<?php echo $theme->slug; ?>" class="theme-container col-md-6 col-lg-4">
								<div class="image-container">
									<img class="theme-screenshot" src="<?php echo $theme->screenshot_url ?>"/>

									<div class="theme-description">
										<p><?php echo $theme->description; ?></p>
									</div>
								</div>
								<div class="theme-details active">
									<span class="theme-name"><?php echo $theme->name . ':' . __( 'Current theme', 'bloog-lite' ); ?></span>
									<a class="button button-secondary customize right" target="_blank" href="<?php echo get_site_url(). '/wp-admin/customize.php' ?>">Customize</a>
								</div>
							</div>

						<?php
						$counter++;
						break;
						}
					}

					// For all other themes.
					foreach ( $themes->themes as $theme ) {
						if( $active_theme != $theme->name ) {

							// Set the argument array with author name.
							$args = array(
								'slug' => $theme->slug,
							);

							// Set the $request array.
							$request = array(
								'body' => array(
									'action'  => 'theme_information',
									'request' => serialize( (object)$args )
								)
							);

							$theme_details = bloog_lite_get_themes( $request );
							?>

							<div id="<?php echo $theme->slug; ?>" class="theme-container col-md-6 col-lg-4 <?php echo $counter % 3 == 1 ? 'no-left-megin' : ""; ?>">
								<div class="image-container">
									<img class="theme-screenshot" src="<?php echo $theme->screenshot_url ?>"/>

									<div class="theme-description">
										<p><?php echo $theme->description; ?></p>
									</div>
								</div>
								<div class="theme-details">
									<span class="theme-name"><?php echo $theme->name; ?></span>

									<!-- Check if the theme is installed -->
									<?php if( wp_get_theme( $theme->slug )->exists() ) { ?>

										<!-- Show the tick image notifying the theme is already installed. -->
										<img data-toggle="tooltip" title="<?php _e( 'Already installed', 'bloog-lite' ); ?>" data-placement="bottom" class="theme-exists" src="<?php echo $directory_uri ?>/images/8dt-right.png"/>

										<!-- Activate Button -->
										<a  class="button button-primary activate right"
											href="<?php echo wp_nonce_url( admin_url( 'themes.php?action=activate&amp;stylesheet=' . urlencode( $theme->slug ) ), 'switch-theme_' . $theme->slug );?>" >Activate</a>
									<?php }
									else {

										// Set the install url for the theme.
										$install_url = add_query_arg( array(
												'action' => 'install-theme',
												'theme'  => $theme->slug,
											), self_admin_url( 'update.php' ) );
									?>
										<!-- Install Button -->
										<a data-toggle="tooltip" data-placement="bottom" title="<?php echo 'Downloaded ' . number_format( $theme_details->downloaded ) . ' times'; ?>" class="button button-primary install right" href="<?php echo esc_url( wp_nonce_url( $install_url, 'install-theme_' . $theme->slug ) ); ?>" ><?php _e( 'Install Now', 'bloog-lite' ); ?></a>
									<?php } ?>

									<!-- Preview button -->
									<a class="button button-secondary preview right" target="_blank" href="<?php echo $theme->preview_url; ?>"><?php _e( 'Live Preview', 'bloog-lite' ); ?></a>
								</div>
							</div>
							<?php
							$counter++;
						}
					}?>
				</div>
			</div>
		</div>
	</div>
<?php
}

// Get all 8Degree themes by using API.
function bloog_lite_get_themes( $request ) {

	// Generate a cache key that would hold the response for this request:
	$key = 'bloog-lite_' . md5( serialize( $request ) );

	// Check transient. If it's there - use that, if not re fetch the theme
	if ( false === ( $themes = get_transient( $key ) ) ) {

		// Transient expired/does not exist. Send request to the API.
		$response = wp_remote_post( 'http://api.wordpress.org/themes/info/1.0/', $request );

		// Check for the error.
		if ( !is_wp_error( $response ) ) {

			$themes = unserialize( wp_remote_retrieve_body( $response ) );

			if ( !is_object( $themes ) && !is_array( $themes ) ) {

				// Response body does not contain an object/array
				return new WP_Error( 'theme_api_error', 'An unexpected error has occurred' );
			}

			// Set transient for next time... keep it for 24 hours should be good
			set_transient( $key, $themes, 60 * 60 * 24 );
		}
		else {
			// Error object returned
			return $response;
		}
	}
	return $themes;
}

/** Plugin Install ***/
function bloog_lite_required_plugins() {

/**
* Array of plugin arrays. Required keys are name and slug.
* If the source is NOT from the .org repo, then source is also required.
*/
$plugins = array(
	array(
		'name'      => '8 Degree Coming Soon Page',
		'slug'      => '8-degree-coming-soon-page',
		'required'  => false,
		'force_activation'   => false,
		'force_deactivation' => true,
		),
	array(
		'name'      => 'AccessPress Social Icons',
		'slug'      => 'accesspress-social-icons',
		'required'  => false,
		'force_activation'   => false,
		'force_deactivation' => true,
		),
	);

	/**
	* Array of configuration settings. Amend each line as needed.
	* If you want the default strings to be available under your own theme domain,
	* leave the strings uncommented.
	* Some of the strings are added into a sprintf, so see the comments at the
	* end of each line for what each argument will be.
	*/
	$config = array(
		'default_path' => '',
		'menu'         => 'bloog-lite-install-plugins',
		'has_notices'  => true,
		'dismissable'  => false,
		'dismiss_msg'  => '',
		'is_automatic' => true,
		'message'      => '',
		'strings'      => array(
			'page_title'                      => __( 'Install Required Plugins', 'bloog-lite' ),
			'menu_title'                      => __( 'Install Plugins', 'bloog-lite' ),
			'installing'                      => __( 'Installing Plugin: %s', 'bloog-lite' ),
			'oops'                            => __( 'Something went wrong with the plugin API.', 'bloog-lite' ),
			'notice_can_install_required'     => _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.','bloog-lite' ),
			'notice_can_install_recommended'  => _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.','bloog-lite' ),
			'notice_cannot_install'           => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.','bloog-lite' ),
			'notice_can_activate_required'    => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.','bloog-lite' ),
			'notice_can_activate_recommended' => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.','bloog-lite' ),
			'notice_cannot_activate'          => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.','bloog-lite' ),
			'notice_ask_to_update'            => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.','bloog-lite' ),
			'notice_cannot_update'            => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.','bloog-lite' ),
			'install_link'                    => _n_noop( 'Begin installing plugin', 'Begin installing plugins','bloog-lite' ),
			'activate_link'                   => _n_noop( 'Begin activating plugin', 'Begin activating plugins','bloog-lite' ),
			'return'                          => __( 'Return to Required Plugins Installer', 'bloog-lite' ),
			'plugin_activated'                => __( 'Plugin activated successfully.', 'bloog-lite' ),
			'complete'                        => __( 'All plugins installed and activated successfully. %s', 'bloog-lite' ),
			'nag_type'                        => 'updated'
			)
);

tgmpa( $plugins, $config );

}
add_action( 'tgmpa_register', 'bloog_lite_required_plugins' );
